@@ -99,3 +99,6 @@ Lang_HelpGuide = "Guida in linea";
 Lang_ExportToIcal = "Export to iCal";
 
 Lang_HasNoMsgs = "$var['folder'] non ha messaggi";
+
+Lang_CalImportTitle = "Import from iCal";
+Lang_CalImportLabel = "Import Calendar in iCal (ics) format:";
