@@ -4,16 +4,15 @@
 // |																|
 // | Function: Select Language										|
 // +----------------------------------------------------------------+
-// | Source-code (C) CalaCode.com 1998-2005 . All rights reserved	|
-// | See http://calacode.com/license.ehtml for license agreement	|
+// | AtMail Open - Licensed under the Apache 2.0 Open-source License|
+// | http://opensource.org/licenses/apache2.0.php                   |
 // +----------------------------------------------------------------+
 // | Date: May 2006													|
 // +----------------------------------------------------------------+
 
 
 // Make sure we are included from install/index.php, exit if not
-if (!defined('ATMAIL_INSTALL_SCRIPT'))
-{
+if (!defined('ATMAIL_INSTALL_SCRIPT')) {
 	// link to installer
 	die("You cannot request this file directly, please use <a href=\"index.php\">the installer</a>");
 }
@@ -26,10 +25,9 @@ if(PHP_OS == 'Darwin') {
 	header('Location: index.php?step=2');
 }
 
-// array of languages supported by @Mail WebMail client
-foreach (glob('../html/*') as $file)
-{
-	if ($file != '.' && $file != '..' && @is_dir("$file/xp"))
+// array of languages supported by Atmail WebMail client
+foreach (glob('../html/*') as $file) {
+	if ($file != '.' && $file != '..' && @is_dir("$file/simple"))
 		$supportedLanguages[] = basename($file);
 }
 
@@ -37,16 +35,14 @@ $errors = array();
 
 // If the form from Stage 1 has been submitted
 // we need to process it
-if (isset($_POST['submit']) && isset($_REQUEST['atmail_lang']))
-{
+if (isset($_POST['submit']) && isset($_REQUEST['atmail_lang'])) {
 	if (in_array($_REQUEST['atmail_lang'], $supportedLanguages))
 		$_SESSION['step1']['lang'] = $lang = $_REQUEST['atmail_lang'];
 	else
 		$errors['invalid_lang'] = true;
 
 	// Save data if there are no errors
-	if (!count($errors))
-	{
+	if (!count($errors)) {
 		// save the setting in session for saving
 		// to Config.php at end of installation
 		$_SESSION['pref']['Language'] = $lang;
@@ -61,5 +57,3 @@ asort($supportedLanguages);
 
 $vars['supportedLanguages'] = $supportedLanguages;
 $vars['output'] .= parse("$htmlPath/step1.phtml", array_merge($errors, $vars));
-
-?>
