@@ -428,7 +428,7 @@ function CycleDOMNodes(ObjMasterNode) {
 // Display the spell-check works on the DOM element
 function CheckDOMSpelling(TextToCk) {
 	if (SpellChkWords.length > 0) {
-		TextToCk = TextToCk.split(/\b/);
+		TextToCk = TextToCk.split(/\s+/);
 		for (var x in TextToCk) {
 			if (TextToCk[x].match(/\w/)) {
 				TextToCk[x] = new Array(TextToCk[x], false);
@@ -446,7 +446,8 @@ function CheckDOMSpelling(TextToCk) {
 				TextToCk[x] = "&nbsp;";
 			}
 		}
-		return TextToCk.join("");
+		var separator=(BrowserType == "ie")?" ":"";
+		return TextToCk.join(separator);
 	} else {
 		return TextToCk;
 	}
@@ -673,6 +674,7 @@ function AddToDicReqChange() {
 }
 
 function ToggleComposeMode(HTML) {
+
 	if (document.getElementById("SpellCheckerBox").style.display == "") {
 		alert("You can not change edit modes whilst using the spell checker.");
 	} else {
@@ -735,6 +737,8 @@ function ToggleComposeMode(HTML) {
 				ObjMRTableTbodyTrTdTextArea.value = ObjTmpDiv.textContent;
 			}
 
+            ObjMRTableTbodyTrTdTextArea.value = ObjMRTableTbodyTrTdTextArea.value.replace(/\s*BODY \{.+?\}/, '');
+            
 			ObjMRTableTbodyTrTd.appendChild(ObjMRTableTbodyTrTdTextArea);
 			ObjMRTableTbodyTrTdTextArea.focus();
 		}
