@@ -2,8 +2,8 @@
 // +----------------------------------------------------------------+
 // | Global.php														|
 // +----------------------------------------------------------------+
-// | Source-code (C) CalaCode.com 1998-2005 . All rights reserved	|
-// | See http://calacode.com/license.ehtml for license agreement	|
+// | AtMail Open - Licensed under the Apache 2.0 Open-source License|
+// | http://opensource.org/licenses/apache2.0.php                   |
 // +----------------------------------------------------------------+
 // | Date: Febuary 2005												|
 // +----------------------------------------------------------------+
@@ -55,6 +55,9 @@ function AtmailGlobal()
 // Auth the user account
 function auth($mailauth=null)
 {
+    $args = array();
+    $this->pluginHandler->triggerEvent('onAuthStart', $args);
+
 	global $domains, $pref;
 
     // Lowercase the pop3host
@@ -135,7 +138,7 @@ function auth($mailauth=null)
 	}
 
 	// Check the user is allowed to acces selected mail server
-	if (!empty($pref['allowed_mailservers']) && !$domains[$this->auth->pop3host])
+	if (!empty($pref['allowed_mailservers']))
 	{
 		$doms = explode(',', $pref['allowed_mailservers']);
 		$chk = 0;
@@ -175,9 +178,7 @@ function auth($mailauth=null)
 	    // If the user selects a different mailserver on the login page
 	    // First try Webadmin > Config > Mailserver field, otherwise MailServer on the login page, otherwise the users domain
 	    $server = ($pref['mailserver']) ? $pref['mailserver'] : $_REQUEST['MailServer'];
-	    //file_put_contents("php://stderr", "STAGE 1 = $server\n");
 	    $server = ($server) ? $server : $this->auth->get_pop3host();
-	    //file_put_contents("php://stderr", "STAGE 2 = $server\n");
 	    $server = str_replace("'", '', $server);
 
 		if (!$domains[$this->auth->pop3host])
@@ -234,7 +235,6 @@ function auth($mailauth=null)
             if ($mail)
 				$mail->quit();
 			exit;
-
         }
         else
 		{
@@ -293,28 +293,27 @@ function auth($mailauth=null)
 
     $status = $this->auth->authuser();
 
-    if ( $status == 1 )
-	{
+    if ( $status == 1 ) {
 		 if (strpos($_SERVER['SCRIPT_NAME'] , 'wap.php') === false && strpos($_SERVER['SCRIPT_NAME'] , 'xhtml.php') === false)
         	$this->httpheaders();
 
         $this->auth_error();
+        return;
     }
 
     elseif ( $status == 3 ) {
         $this->userdisabled();
+        return;
     }
-    else
-	{
-        // Update the LastLogin timestamp
-        $this->auth->update_lastlogin();
-        $this->username = $this->auth->get_username();
-        $this->pop3host = $this->auth->get_pop3host();
-        $this->account  = $this->auth->get_account();
-		$this->loadprefs();
-		$this->MailAuth = $this->MailA;
-		$this->auth->authenticated = true;
-    }
+    
+    // Update the LastLogin timestamp
+    $this->auth->update_lastlogin();
+    $this->username = $this->auth->get_username();
+    $this->pop3host = $this->auth->get_pop3host();
+    $this->account  = $this->auth->get_account();
+    $this->loadprefs();
+    $this->MailAuth = $this->MailA;
+    $this->auth->authenticated = true;
 
 	// Make our sample account data
 	//if($this->demouser == '1')
@@ -338,7 +337,7 @@ function loadprefs()
     if (isset($domains[$this->pop3host])) {
     	$this->MailType = 'file';
     }
-    
+
 	// If users Language is empty set to default
 	if (!$this->Language)
 	{
@@ -366,15 +365,18 @@ function loadprefs()
 	// Create our temporary directory
 	if (!is_dir($this->tmpdir))
 		mkdir($this->tmpdir,0777);
-		
+
 	// LeaveMsgs = 0 is not spported as yet
 	$this->LeaveMsgs = 1;
-	
+
     if ((isset($_REQUEST['UseSSL']) && $_REQUEST['UseSSL'] == 1) || strpos($_REQUEST['MailType'], 's')) {
         $this->UseSSL = 1;
     } else {
         $this->UseSSL = 0;
     }
+
+    $args = array();
+    $this->pluginHandler->triggerEvent('onLoadPrefs', $args);
 }
 
 
@@ -387,7 +389,7 @@ function loadpersonalities($type=null)
 
 	if ($type)
 	{
-		$text = "$this->ReplyTo::";
+		$text = "$this->ReplyTo::$this->username@$this->pop3host::";
 
 		foreach ($users as $user)
 			$text .= "$user::";
@@ -410,9 +412,10 @@ function loadpersonalities($type=null)
 				$local_name = $this->ReplyTo;
 			}
 
+			$text .= "<option value='$this->ReplyTo' selected>$local_name</option>";
 		}
 
-		$text = "<option value='$this->username@$this->pop3host'>$local_name</option>";
+		$text .= "<option value='$this->username@$this->pop3host'>$this->username@$this->pop3host</option>";
 
 		if (is_array($users))
 		{
@@ -630,8 +633,58 @@ function startpage()
     $this->db->sqldo($query, $data);
 }
 
+function saveautoreply_plesk($id, $autoreply)
+{
+
+	echo "IN HERE FOR PLESK, SAVE TO THEIR DB" . $id . ':' . $autoreply; 
+	//assume that PHP bug of not reliably being able to simultaneously connect to multiple database servers still exists
+	// so will copy pref, mod $pref[] settings to connect to psa database
+	//connect to psa database
+	//execute simple query
+	//recreate valid/origional $this->db
+	global $pref;
+	$previous_sql_user = $pref['sql_user'];
+	$previous_sql_pass = $pref['sql_pass'];
+	$previous_sql_table = $pref['sql_table']; //table ~= database
+	//set psa db settings
+	$pref['sql_user'] = 'admin';
+	$pref['sql_pass'] = file_get_contents('/etc/psa/.psa.shadow');
+	$pref['sql_table'] = 'psa';
+	$this->Global_Base(); //creates temporary psa database connection
+	//if strlen($autoreply) < 1 then disable autoreply
+	$query = 'SELECT  = ? WHERE Account= ?';
+	$query = 'UPDATE  SET AutoReply = ? WHERE Account= ?';
+	$data = array( $autoreply, $this->auth->get_account() );
+	$res = $this->db->sqldo($query, $data);
+	
+	
+	//now recreate origional db link
+	$pref['sql_user'] = $previous_sql_user;
+	$pref['sql_pass'] = $previous_sql_pass;
+	$pref['sql_table'] = $previous_sql_table;
+	$this->Global_Base(); //creates origional database connection
+	
+	
+	// Prepare the SQL query
+    //$query = 'UPDATE '.$this->db->get('UserSettings').' SET AutoReply = ? WHERE Account= ?';
+    //$data = array( $autoreply, $this->auth->get_account() );
+	//$this->db->sqldo($query, $data);
+    //$res = $this->db->sqldo($query, $data);
+}
+
+function saveforward_plesk($id, $forward)
+{
+
+	echo "SAVE THE FORWARD HERE". $this->username. '@' . $this->pop3host . ':' . $id . ':' . $forward;
+	$q = "UPDATE ";
+
+}
+
+
 function savesettings()
 {
+	global $pref;
+	
 	// Don't allow names with a ' breaks JS functions
 	$RealName = str_replace(array(',', "'"), '', $_REQUEST['RealName']);
 
@@ -648,6 +701,9 @@ function savesettings()
 	$autotrash 	= ($settings['AutoTrash'])? $settings['AutoTrash'] : 0;
 	$refresh 	= ($settings['Refresh'])? $settings['Refresh'] : 0;
 
+	if(false && $pref['plesk'] == 1) //disabled 
+		$this->saveautoreply_plesk($autoreply);
+
 	if ($settings['LoginType'] == 'ajax')
 	{
 		$LoginType = 'simple';
@@ -752,6 +808,13 @@ Account			= ?
 		$forward = "";
 
 
+	// Trigger onSetAutoReply event
+	$args = array('autoreply' => $autoreply, 'forward' => $forward, 'account' => $this->Account);
+	$this->pluginHandler->triggerEvent('onSetAutoReply', $args);
+	if (isset($args['handled'])) {
+	    return;
+	}
+
     // Next, update the users AutoReply and mail-forwarding options if required
 	$data = array($autoreply, $forward, "$this->username@$this->pop3host");
     $res = $this->db->sqldo("UPDATE Users set AutoReply = ?, Forward = ? where Account = ?", $data);
@@ -1085,7 +1148,7 @@ function getsort($type, $format=null)
             $h[$v[$type]] = $v['EmailFolder'];
         else
             // Build the select box
-            $tmp .= "<option value=\"" . base64_encode($v[$type]) . "\">" . htmlentities($v[$type]) . " -&gt; {$v['EmailFolder']}</option>";
+            $tmp .= "<option value=\"" . base64_encode($v[$type]) . "\">" . htmlentities($v[$type], ENT_QUOTES, 'UTF-8') . " -&gt; {$v['EmailFolder']}</option>";
 
     }
 
@@ -1359,7 +1422,7 @@ function print_mailtypes()
         } elseif ($pref['mail_type_ssl'] == 'force') {
             $select = "<input type='hidden' name='MailType' value='pop3s'>";
         } elseif ($pref['mail_type_ssl'] == 'allow') {
-            $select = "<select name='MailType'><option value='pop3'>POP3</option><option value='pop3s'>POP3 Secure</option></select>";
+            $select = "<select name='MailType' class='protocol'><option value='pop3'>POP3</option><option value='pop3s'>POP3 Secure</option></select>";
             $select = str_replace("value='$type'", "value='$type' selected", $select);
         }
     } elseif ( $pref['mail_type'] == 'imap') {
@@ -1368,18 +1431,18 @@ function print_mailtypes()
         } elseif ($pref['mail_type_ssl'] == 'force') {
             $select = "<input type='hidden' name='MailType' value='imaps'>";
         } elseif ($pref['mail_type_ssl'] == 'allow') {
-            $select = "<select name='MailType'><option value='imap'>IMAP</option><option value='imaps'>IMAP Secure</option></select>";
+            $select = "<select name='MailType' class='protocol'><option value='imap'>IMAP</option><option value='imaps'>IMAP Secure</option></select>";
             $select = str_replace("value='$type'", "value='$type' selected", $select);
         }
     } elseif ( $pref['mail_type'] == 'pop3imap') {
         if ($pref['mail_type_ssl'] == 'deny') {
-            $select = "<select name='MailType'><option value='imap'>IMAP</option><option value='pop3'>POP3</option></select>";
+            $select = "<select name='MailType' class='protocol'><option value='imap'>IMAP</option><option value='pop3'>POP3</option></select>";
             $select = str_replace("value='$type'", "value='$type' selected", $select);
         } elseif ($pref['mail_type_ssl'] == 'force') {
-            $select = "<select name='MailType'><option value='imaps'>IMAP Secure</option><option value='pop3s'>POP3 Secure</option></select>";
+            $select = "<select name='MailType' class='protocol'><option value='imaps'>IMAP Secure</option><option value='pop3s'>POP3 Secure</option></select>";
         $select = str_replace("value='$type'", "value='$type' selected", $select);
         } elseif ($pref['mail_type_ssl'] == 'allow') {
-            $select = "<select name='MailType'><option value='imap' >IMAP</option><option value='imaps'>IMAP Secure</option><option value='pop3'>POP3</option><option value='pop3s'>POP3 Secure</option></select>";
+            $select = "<select name='MailType' class='protocol'><option value='imap' >IMAP</option><option value='imaps'>IMAP Secure</option><option value='pop3'>POP3</option><option value='pop3s'>POP3 Secure</option></select>";
             $select = str_replace("value='$type'", "value='$type' selected", $select);
         }
     }
@@ -1394,16 +1457,16 @@ function clean_tmp($dir=null) {
 	$sessionId = session_id();
 	$files = array();
 
-    $dh = opendir($pref['user_dir']."/tmp/$dir");
+    if (is_dir($pref['user_dir']."/tmp/$dir") && $dh = opendir($pref['user_dir']."/tmp/$dir")) {
 
-	while (false !== ($file = readdir($dh))) {
-	  	array_push($files, $file); //echo "$file\n";
-	}
-
-    closedir($dh);
-
-	$this->clean_tmp_dir("{$pref['user_dir']}/tmp/$dir", $files);
+    	while (false !== ($file = readdir($dh))) {
+    	  	array_push($files, $file); //echo "$file\n";
+    	}
+    
+        closedir($dh);
 
+	    $this->clean_tmp_dir("{$pref['user_dir']}/tmp/$dir", $files);
+    }
 }
 
 function clean_tmp_dir($dir=null, $files)
@@ -1757,7 +1820,7 @@ function bgtrans()
 function escape_pathname($path)
 {
 	// Escape going down one directory and pipes
-	$path = str_replace('..', '\.\.', $path); //~ s/\.\.//g;
+	$path = str_replace('../', '/', $path); //~ s/\.\.//g;
 	$path = str_replace('|', '\|', $path); //~ s/\|//g;
 	return $path;
 }
@@ -1887,7 +1950,6 @@ function generatepermissions($user, $db, $field, $accounts)
 
 				$permissions .= $value . ",";
 
-				//file_put_contents("php://stderr", "PERMS = $permissions\n");
     		}
     		else
     		{
@@ -2154,20 +2216,18 @@ function escape_images($txt)
 	$tmp = strtolower($txt);
 
 	// Watch out for javascript in img src URL,  IE doesn't handle these very well. Addresses SA18874.
-	if (strpos($tmp, '<img') !== false  && strpos($tmp, 'java') !== false && strpos($tmp, 'script:') !== false)
-		$txt = preg_replace('/<img.*?>/', '<img src="" alt="Image Block Forced">', $txt);
+	$txt = preg_replace('/<img [^>]+?javascript:.+?>/is', '<img src="" alt="Image Block Forced">', $txt);
 
 	// Skip if we trust all images
-	if ($this->DisplayImages == 1 || $_REQUEST['DisplayImages'] == 1 )
+	if ($this->DisplayImages == 1 || (is_array($_SESSION['DisplayImages']) && in_array($_REQUEST['id'], $_SESSION['DisplayImages'])))
 		return $txt;
 
 	// Block the image tags - Rewrite
 	if (strpos($tmp, '<img') !== false)
 	{
 		$this->BlockImages++;
-		$txt = preg_replace('/<img.*?>/i', '<img src="" alt="Blocked image">', $txt);
+		$txt = preg_replace('/<img .+?>/is', '<img src="" alt="Blocked image">', $txt);
 	}
-
 	return $txt;
 }
 
@@ -2178,6 +2238,10 @@ function escape_images($txt)
  */
 function load_displayimages()
 {
+
+	if(!$this->db->UserSettings)
+	return;
+
 	return $this->db->sqlgetfield("SELECT DisplayImages
 	                               FROM {$this->db->UserSettings}
 	                               WHERE Account = ?", "$this->username@$this->pop3host");
@@ -2286,19 +2350,6 @@ function rmtree($dir)
 	return false;
 }
 
-function generate_demouser($domain)
-{
-
-	// Generate a demo user for the online demo only
-	$output = file_get_contents("http://demo.atmail.com/atmail.php?username=demo&pop3host=demo.atmail.org&password=demo&LoginType=ajax&Language=english");
-
-	preg_match('/<title>@Mail - (.*?)@/', $output, $match);
-
-	file_put_contents("php://stderr", "IN THE GEN DEMO USER\n");
-	file_put_contents("php://stderr", $match[1]);
-	
-	return $match[1];
-}
 
 
     function do_branding()
