@@ -13,6 +13,8 @@ class PluginHandler
 	
 	var $plugins = array();
 	
+	var $handledEvents = array();
+	
 	
 	function PluginHandler($pluginDir)
 	{
@@ -57,4 +59,17 @@ class PluginHandler
 	{
 		$this->$var = $value; 
 	}
+	
+	
+	function isHandled($event)
+	{
+	    foreach ($this->plugins as $plugin) {
+	        if ($plugin->handlesEvent($event)) {
+	            return true;
+	        }
+	    }
+	    
+	    return false;
+	}
+	
 }
