@@ -22,7 +22,8 @@ class ReadMsg
 	var $inline;
 	var $emailattachname;
 	var $attachedemails = array();
-
+    var $processedSections = array();
+    
 	/**
 	 * Class constructor
 	 *
@@ -179,7 +180,7 @@ class ReadMsg
 	    $this->bcc = $this->parser->get_header_field('BCC');
 	    $this->to = $this->parser->get_header_field('To');
 
-		$this->VideoMail = $this->quote_header($this->parser->get_header_field('X-VideoMail'));
+	    $this->VideoMail = $this->quote_header($this->parser->get_header_field('X-VideoMail'));
 		if ($this->VideoMail)
 			$this->VideoMail .= "/mini" ;
 
@@ -187,14 +188,17 @@ class ReadMsg
 		foreach (array('from', 'replyto', 'subject', 'to', 'cc', 'bcc') as $field)
 		{
 			// Store the encoding of the email-message
-			if (preg_match('/\s*=\?([^\?]+)\?[QqBb]/', $this->$field, $match))
+			if (preg_match('/\s*=\?([^\?]+)\?([QqBb])/', $this->$field, $match))
 			{
 				$this->Encoding = $match[1];
-				$this->$field = preg_replace('/\s*=\?([^\?]+)\?[Qq]\?([^\?]+)?\?=/e', "\$this->mail->decode_language('\\1', GetMail::decode_mime_head('\\1', '\\2'))", $this->$field);
-				$this->$field = preg_replace('/\s*=\?([^\?]+)\?[Bb]\?([^\?]+)?\?=/e', "\$this->mail->decode_language('\\1', base64_decode('\\2'))", $this->$field);
-			}
-			else
+				if (strtoupper($match[2]) == 'Q') {
+				    $this->$field = preg_replace('/\s*=\?([^\?]+)\?[Qq]\?([^\?]+)?\?=/e', "\$this->mail->decode_language('\\1', GetMail::decode_mime_head('\\1', stripslashes('\\2')))", $this->$field);
+				} else {
+				    $this->$field = preg_replace('/\s*=\?([^\?]+)\?[Bb]\?([^\?]+)?\?=/e', "\$this->mail->decode_language('\\1', base64_decode('\\2'))", $this->$field);
+				}
+			} else {
 				$this->$field = $this->mail->decode_language($this->Charset, $this->$field);
+			}
 		}
 
 	    $this->date = $this->parser->get_header_field('Date');
@@ -203,14 +207,14 @@ class ReadMsg
 
 		$date = $this->mail->calc_timezone($date);
 		$time = strtotime($date);
-		setlocale(LC_TIME, strtolower($this->Language), 'en_US');
-
-		if ($this->Language == "japanese")
-			$this->date = strftime("$this->mail->DateFormat %a $this->mail->TimeFormat", $time);
-		else {
-			$this->date = strftime("%a " . $this->mail->DateFormat . " " . $this->mail->TimeFormat, $time);
-			$this->date = iconv('iso-8859-1', "UTF-8", $this->date);
-		}
+        if ($this->Language == "japanese") {
+            setlocale(LC_TIME, 'ja_JP.UTF-8', 'en_US');
+            $this->date = strftime("{$this->mail->DateFormat} %a {$this->mail->TimeFormat}", $time);
+        } else {
+            setlocale(LC_TIME, strtolower($this->Language), 'en_US');
+            $this->date = strftime("%a " . $this->mail->DateFormat . " " . $this->mail->TimeFormat, $time);
+            $this->date = iconv('iso-8859-1', "UTF-8", $this->date);
+        }
 
 	    // Take away the timezone and seconds
 	    $this->date = preg_replace('/:\d\d \+?-?\d{4}.*/', '', $this->date);
@@ -296,6 +300,21 @@ class ReadMsg
 		}
 
 	    $this->dump_entity();
+
+	    if (isset($this->multiparttxt) && !empty($this->multiparttxt)) {
+            $this->multiparttxt = $atmail->escape_jscript($this->multiparttxt);
+        }
+
+	    if (isset($this->html) && !empty($this->html)) {
+	        $this->html = $atmail->escape_jscript($this->html);
+	        if (isset($this->multiparttxt)) $this->html .= $this->multiparttxt;
+	    }
+
+	    if (isset($this->txt) && !empty($this->txt)) {
+            $this->txt = $atmail->escape_jscript($this->txt);
+	        if (isset($this->multiparttxt)) $this->txt .= $this->multiparttxt;
+        }
+
 		$this->scan_inline();
 
 		// Fix an error where certain messages cannot be displayed ( e.g Apple mailers as multipart msgs )
@@ -323,7 +342,7 @@ class ReadMsg
 
 	        $body = $part->get_body();
 
-	 		$body = explode("\n", $body);
+	        $body = explode("\n", $body);
 
 	 		// Break up long lines in HTML emails without
 	 		// breaking any tags or HTML entities
@@ -333,6 +352,8 @@ class ReadMsg
 	 			$buff = '';
 
 	 			foreach ($body as $line) {
+	 			    // strip unnecessary whitespace
+                    $line = preg_replace("/\s+/", ' ', $line);
 
 	 				$lineSize = strlen($line);
 					$last = 0;
@@ -369,10 +390,8 @@ class ReadMsg
 
 			// end break up long HTML lines
 
-
 			$this->Charset = $part->get_charset();
 
-
 			// Detect messages forwarded as attachments
 	        if (strpos(strtolower($part->content_type), 'message/rfc822') !== false)
 	        {
@@ -381,13 +400,14 @@ class ReadMsg
 
 			}
 			// Ignore multipart/alternative messages that contain a text attachment of the same message ( decoded from HTML )
-			elseif ((($type == 'text' || $type == 'message') && $this->mimetype != 'multipart/alternative'
-			     && ($subtype == 'plain' || preg_match('/text\/(v|i)?calendar/i', $this->mimetype)) && !$part->is_attachment()) || !$this->mimetype)
+			elseif ((($type == 'text' || $type == 'message') && $part->parent_mime_type() != 'multipart/alternative'
+			     && ($subtype == 'plain' || preg_match('/text\/(v|i)?calendar/i', $this->mimetype)) && !$part->is_attachment())
+			     || !$this->mimetype || $this->mimetype == 'multipart/report')
 			{
 	        	foreach ($body as $line)
 	        	{
 					$line = $this->mail->decode_language($this->Charset, $line);
-	                $line = $atmail->escape_jscript($line);   // Check jscript attacks
+	                //$line = $atmail->escape_jscript($line);   // Check jscript attacks
 					$line = $this->scanpgp($line);
 					$line = htmlentities($line, ENT_COMPAT, 'UTF-8');
 	                $line = $this->quoteurl($line);
@@ -442,11 +462,11 @@ class ReadMsg
 			//elseif(($type == 'text' || $type == 'message') && $this->txt && !$this->html && $subtype == 'html' && strpos($part->parent_ctype, 'alternative') !== false ||
 	        //($type == 'text' || $type == 'message') && !$this->html && !$this->txt)
 	        elseif (($type == 'text' || $type == 'message') && !$part->is_attachment()
-	        && (($this->mimetype == 'multipart/alternative')
-	        || ($this->mimetype != 'multipart/alternative' && !$this->txt && !$this->html)
+	        && (($part->parent_mime_type() == 'multipart/alternative')
+	        || ($part->parent_mime_type() != 'multipart/alternative' && !in_array($part->parent_ctype, $this->processedSections))
 	        || $this->attachedemail))
 	        {
-                if ($subtype == 'html')
+                if (!$this->html && $subtype == 'html')
                 {
                     $this->txt = '';
 
@@ -475,20 +495,19 @@ class ReadMsg
 
 						$line = $this->_clean_tags($line);
 
-						$line = $atmail->escape_jscript($line);
+						//$line = $atmail->escape_jscript($line);
 						//$line = $this->scanpgp($line);
 	                    $this->html .= $line . "\n";
-
 	                }
 	            }
 
-                if ($subtype == 'plain')
+                elseif (!$this->txt && $subtype == 'plain')
                 {
                     foreach ($body as $line)
                     {
 						$line = $this->mail->decode_language($this->Charset, $line);
-						if(isset($atmail))
-                        $line = $atmail->escape_jscript($line);   // Check jscript attacks
+						//if(isset($atmail))
+                        //$line = $atmail->escape_jscript($line);   // Check jscript attacks
 
 						//$line = $this->scanpgp($line);
 						$line = htmlentities($line, ENT_COMPAT, 'UTF-8');
@@ -504,8 +523,8 @@ class ReadMsg
 	            }
 	        }
 
-			// An inline / CID image. Display the image embeded into the email-message
-	        elseif ($type == 'image' && $part->get_contentid() && $subtype != 'tiff')
+			// A CID image. Display the image embeded into the email-message
+	        elseif ($part->is_image() && $part->get_contentid() && $subtype != 'tiff')
 	        {
 				$path = $part->get_path();
 				$cid = $part->get_contentid();
@@ -527,8 +546,10 @@ class ReadMsg
                 $this->attachname[$filename]['type'] = "pic";
 	            $this->attachname[$filename]['size'] = $size;
 	            $this->attachname[$filename]['path'] = $path;
-	            $this->attachname[$filename]['name'] = $this->mail->quote_header($filename);
+	            $this->attachname[$filename]['rawname'] = $filename;
+	            $this->attachname[$filename]['name'] = $this->mail->quote_header($part->get_filename());
 	            $this->attachname[$filename]['cid']  = $cid;
+	            $this->attachname[$filename]['desc'] = $part->get_header_field("Content-Description");
 
 	            # Save the name correctly, when forwarding
 	            #$self->{attachname}{$filename}{mime} = $this->mail->quote_header($filename); $entity->head->mime_attr('content-type.name') );
@@ -587,6 +608,8 @@ class ReadMsg
 	            $this->attachname[$filename]['mime'] = $part->get_mime_type();
 				$this->attachname[$filename]['desc'] = $part->get_header_field("Content-Description");
             }
+
+            $this->processedSections[] = $part->parent_ctype;
 	    }
 	}
 
@@ -773,7 +796,17 @@ class ReadMsg
 	{
 		foreach ($this->inline as $k => $v)
 		{
-			$this->html = str_replace("cid:$k", $v, $this->html);
+			if (strpos($this->html, "cid:$k") !== false) {
+			    $this->html = str_replace("cid:$k", $v, $this->html);
+			} else {
+			    // cid reference did not exist in the HTML
+			    // so we should display the image as an attachment
+			    foreach ($this->attachname as $k2 => $v2) {
+			        if ($v2['cid'] == $k) {
+			            $this->attachname[$k2]['inline'] = false;
+			        }
+			    }
+			}
 		}
 
 		$this->html = preg_replace('/js:opencompose/i', 'javascript:opencompose', $this->html);
@@ -786,8 +819,6 @@ class ReadMsg
 		if (strpos($emailmsg, '-----BEGIN PGP MESSAGE-----') === false)
 			return;
 
-		$emailmsg = str_replace(array('<br>', '<BR>'), "\n", $emailmsg);
-
 		require_once('PGP.php');
 		$userWrkDir = ($this->mail->MailDir) ? $this->mail->MailDir : $atmail->tmpdir;
 		$ownFile = $atmail->tmpdir . ".ht.$this->SessionID";
@@ -829,8 +860,7 @@ class ReadMsg
 			$line = str_replace(array('<BR>', '<br>'), '', $line);
 			$this->MailEncryptPGP .= $line;
 
-			$this->MailEncrypt .= "<input type=\"hidden\" name=\"UserPgpKey\" value=\"$this->MailEncryptPGP\">
-	</form>";
+			$this->MailEncrypt .= "<textarea name=\"UserPgpKey\" style=\"display:none;\">$this->MailEncryptPGP</textarea></form>";
 
 			$this->MailEncryptDone = 1;
 			$line = "";
@@ -839,15 +869,16 @@ class ReadMsg
 		elseif ($this->MailEncrypt)
 		{
 			$line = str_replace(array('<BR>', '<br>'), '', $line);
-			$this->MailEncryptPGP .= $line;
+            $line = trim($line);
+			$this->MailEncryptPGP .= "$line\n";
 			$line = "";
 		}
 
 		elseif (strpos($line, '-----BEGIN PGP PUBLIC KEY BLOCK-----') !== false)
 		{
 			$from = $this->from;
-			$from = preg_replace('/.*&lt;/', '', $from);
-			$from = str_replace('&gt;', '', $from);
+			$from = preg_replace('/.*(&lt;|<)/', '', $from);
+			$from = str_replace(array('&gt;', '>'), '', $from);
 
 			$this->MailEncrypt = <<<_EOF
 <script language="Javascript">
@@ -877,7 +908,8 @@ function addpgp(){
 _EOF;
 
 			$line = str_replace(array('<BR>', '<br>'), '', $line);
-			$this->MailEncryptPGP = $line;
+			$line = trim($line);
+            $this->MailEncryptPGP .= "$line\n";
 			$line = "";
 		}
 
@@ -926,7 +958,11 @@ _EOF;
 	return htmlspecialchars_decode($field);
     }
 
-	function clean_html_to_text($msg)	{
+	function clean_html_to_text($msg=null)	{
+
+		if(!$msg)
+		$msg = &$this->html;
+
 		$msg = $this->strip_style($msg);
 
         // strip out leading whitespace
@@ -953,5 +989,21 @@ _EOF;
 		return $msg;
 	}
 
+	function cleanEmailAddress($address)
+	{
+    	$address = trim($address);
+
+        // add quotes around personal parts
+        $address = preg_replace('/(^|,|;)\s*([^"\']{1}[^@]+?[^"\',;]{1})(?!Group)\s+([^\s]+?@[a-z0-9.\-]+)/i', '$1"$2" $3', $address);
+
+        // add angle brackets around address parts
+        $address = preg_replace('/(?<!"<\')([^\s]+?@[a-z0-9.\-]+)(?!>|"|\')(,|;|$)/i', '<$1>$2', $address);
+
+        // Convert single quotes to double quotes
+        $address = preg_replace("/'([^<]+?)' </", '"$1" <', $address);
+
+        return $address;
+	}
+
 } // end ReagMsg
 ?>
