@@ -127,10 +127,7 @@ class SendMsg
 		$this->RawEmailSubject = $this->EmailSubject;
 
 	    // Format the date correctly
-	    // Let the SMTP / Sendmail binary decide our timezone / date
-		//ctimelang("english");
-		//$this->Date = strftime( "%a, %d %h %Y %T %Z", time());
-	    $this->Date = date("D, j M Y H:i:s O", time());
+	    $this->Date = date('r');
 
 	    // return an error if To: field contains only , or ;
         if (strlen($this->EmailTo) == 0 || (!preg_match('/\@/', $this->EmailTo) && (preg_match('/,/', $this->EmailTo))) && $this->EmailBox != "Draft")
@@ -323,7 +320,7 @@ EOF;
 		        $this->$type = str_replace(array(';', ' Shared Group', ' Group'), array(',', '@SharedGroup', '@Group'), $this->$type);
 
 		        // Remove "smart quotes" (aka dumb quotes)
-		        $smartquotes = array('“', '”', '‘', '’', "\x98", "\x99", "\x8c", "\x9d", chr(147), chr(148), chr(146), 'R20;', 'R21', 'R16;', 'R17');
+		        $smartquotes = array('“', '”', '‘', '’', "\x98", "\x99", "\x8c", "\x9d", chr(147), chr(148), chr(146), 'R20;', 'R21;', 'R17;', 'R16;');
 
 		        $this->$type = str_replace($smartquotes, '"', $this->$type);
 
@@ -636,7 +633,7 @@ EOF;
 	{
 		$emailbox = ($this->EmailBox)? $this->EmailBox : 'Sent';
 
-	    $this->sql->savemsg(array(
+	    return $this->sql->savemsg(array(
 	      'Account'      => $this->Account,
 	      'EmailSubject' => $this->EmailSubject,
 	      'EmailTo'      => str_replace(array('@SharedGroup', '@Group'), array(' Shared Group', ' Group'), $this->EmailTo),
@@ -743,6 +740,13 @@ EOF;
 	            return false;
 	    }
 
+		// Check if we should use each account's username and password
+		// for the SMTP
+		if ($pref['smtp_per_account_auth']) {
+		    $pref['smtpauth_username'] = $atmail->auth->get_username();
+		    $pref['smtpauth_password'] = $atmail->auth->get_password();
+		}
+		
 		// Optionally authenticate with the SMTP server
 		if ($pref['smtpauth_username'] && $pref['smtpauth_password']) {
 			if($smtp->auth($pref['smtpauth_username'], $pref['smtpauth_password']) !== true) {
@@ -1074,7 +1078,7 @@ EOF;
 	    $local_array = explode(".", $email_array[0]);
 	    for ($i = 0; $i < sizeof($local_array); $i++)
 	    {
-	        if (!ereg("^(([A-Za-z0-9!#$%&'*+/=?^_`{|}~-][A-Za-z0-9!#$%&'*+/=?^_`{|}~\.-]{0,63})|(\"[^(\\|\")]{0,62}\"))$", $local_array[$i]))
+	        if (!ereg("^(([A-Za-z0-9!#$%&'*+/=?^_`{|}~\-][A-Za-z0-9!#$%&'*+/=?^_`{|}~.\-]{0,63})|(\"[^(\\|\")]{0,62}\"))$", $local_array[$i]))
 	        {
 	            return false;
 	        }
