@@ -5,8 +5,8 @@
 // | Function: Wrapper class for PHP pspell functions and aspell  	|
 // |           command line utility                                 |
 // +----------------------------------------------------------------+
-// | Source-code (C) CalaCode.com 1998-2008 . All rights reserved	|
-// | See http://calacode.com/license.ehtml for license agreement	|
+// | AtMail Open - Licensed under the Apache 2.0 Open-source License|
+// | http://opensource.org/licenses/apache2.0.php                   |
 // +----------------------------------------------------------------+
 // | Date: March 2006												|
 // +----------------------------------------------------------------+
@@ -33,7 +33,7 @@ class spellChecker
 	 */
 	function spellChecker($dict, $account, $use_pspell=false)
 	{
-		global $atmail;
+		global $atmail, $pref;
 
 		$this->personal_words = $atmail->db->sqlarray("select Word from SpellCheck where SUnique='0' and Account=?", $account);
 		$this->suggestions = array();
@@ -52,7 +52,7 @@ class spellChecker
 
 			// Execute the aspell command and open file pointers for input/output
 			$descriptorspec = array(array("pipe", "r"), array("pipe", "w"));
-			$this->aspell_proc = proc_open("aspell -a -l $dict --sug-mode=fast", $descriptorspec, $pipes);
+			$this->aspell_proc = proc_open("{$pref['aspell_path']} -a -l $dict --sug-mode=fast --encoding=utf-8", $descriptorspec, $pipes);
 			$this->aspell_input = $pipes[0];
 			$this->aspell_output = $pipes[1];
 
