@@ -17,6 +17,10 @@ require_once('Session.php');
 
 session_start();
 
+if (isset($_REQUEST['DisplayImages']) && $_REQUEST['DisplayImages'] == 1) {
+    $_SESSION['DisplayImages'][] = $_REQUEST['id'];
+}
+
 $var = array();
 
 $atmail = new AtmailGlobal();
@@ -65,8 +69,7 @@ $var['atmailstyle'] .= $atmail->parse("html/$atmail->Language/$atmail->LoginType
 
 // Which email to read
 $var['id']     = $_REQUEST['id'];
-$var['folder'] = urldecode($_REQUEST['folder']);
-
+$var['folder'] = $_REQUEST['folder'];
 $var['print']  = $_REQUEST['print'];
 $var['cache']  = $_REQUEST['cache'];
 
@@ -360,7 +363,7 @@ function parse_attachments(&$obj)
 					  'FileName' => rawurlencode($v['rawname']),
 					  'Size'     => $v['size'],
 					  'Desc'     => $v['desc'],
-					  'Download' => $obj->myescape($v['name']),
+					  'Download' => rawurlencode($v['name']),
 					  'Name'     => $v['name'],
 					  'Icon'     => $var['icon'],
 					  'Target'   => $target)
@@ -388,7 +391,15 @@ function parse_attachments(&$obj)
 
 function cleanText($txt)
 {
-	return str_replace(']]>', '', preg_replace('/\x04/', '', $txt));
+    foreach (range(0, 31) as $chr) {
+        // Leave in linefeeds
+        if ($chr == 10) {
+            continue;
+        }
+        $txt = str_replace(chr($chr), '', $txt);
+    }
+
+	return str_replace(']]>', '', $txt);
 }
 
 
