@@ -476,6 +476,9 @@ function search_start()
 			elseif ($atmail->MailType == 'imap')
 			{
 				$db['EmailSize'] = $sizes[$folder][$i];
+				
+				// Get the message flag for IMAP search
+				$db['UIDL'] = $mail->mailer->mailer->getFlags($i, true);
 			}
 
 	        $db = $mail->clean_header($db, array('TimeZone' => $atmail->TimeZone));
@@ -521,8 +524,11 @@ EOF;
 			}
 			else
 				$var['emails'] .= $atmail->parse("html/$atmail->Language/$atmail->LoginType/searchentry.html", $db);
-		}
+				
+                    $args = array($db['EmailUIDL']);
+                    $atmail->pluginHandler->triggerEvent('onAddEmailSearchResult', $args); 
 	}
+}
 
     if (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false)
         $var['browser'] = "ie";
@@ -556,82 +562,4 @@ EOF;
 	$mail->quit();
 }
 
-
-/**
- * Build an XML representation of the search
- * results and send to the browser
- *
- * @param array $data an array of associative arrays
- * 			representing the found emails data
- * @param array $folders array of folder names the user has
- * @return void
- */
-function sendXMLSearchResults($data, $folders)
-{
-	global $mail;
-
-	$xml = <<<XML
-<?xml version="1.0" ?>
-<UserEmails>
-	<MsgList>
-
-XML;
-
-	$search_size = count($data);
-	$msg_total = 0;
-
-	// Iterate through all the found emails
-	// and build the XML
-	foreach ($data as $email)
-	{
-		$MsgIcon = $email['UIDL'] ? 'read' : 'unread';
-		$attach = (strpos($email['EmailAttach'], 'trans.gif') === false) ? 1 : 0;
-
-		$xml.= <<<XML
-		<Msg ID="{$email['id']}" Epoch="{$email['EmailDateEpoc']}" Date="{$email['EmailDate']}" Priority="" Size="{$email['EmailSize']}" SizeRaw="" MsgIcon="$MsgIcon" Attach="$attach">
-			<Folder>
-				<![CDATA[ {$email['folder']} ]]>
-			</Folder>
-			<Subject>
-				<![CDATA[ {$email['EmailSubject']} ]]>
-			</Subject>
-			<From>
-				<![CDATA[ {$email['EmailFrom']} ]]>
-	  		</From>
-  		</Msg>
-XML;
-	}
-
-	// Create the XML structure for the folder list
-	$folder_list = '';
-	foreach ($folders as $folder)
-	{
-		list($count,) = $mail->sizefolder($folder);
-		$folder_list .= <<<XML
-			<Fol Name="$folder" Count="$count" Icon="$folder" State="" />
-
-XML;
-
-		$msg_total += $count;
-	}
-
-	// Append some more XML data
-	$time = time();
-	$xml .= <<<XML
-
-		</MsgList>
-		<Timestamp>$time</Timestamp>
-		<FolderList>
-$folder_list
-			<Fol Name="Search" Count="$search_size" Icon="search" State="" />
-  		</FolderList>
-	<MsgNav Total="$msg_total" View="25" Start="0" />
-</UserEmails>
-XML;
-
-	// send the appropriate header on echo the XML
-	header("Content-type: text/xml; charset: utf-8");
-	echo $xml;
-}
-
 ?>
